==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/APIServerListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface APIServerListFluent<A extends APIServerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,APIServer item);
  public A setToItems(Integer index,APIServer item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.APIServer... items);
  public A addAllToItems(Collection<APIServer> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.APIServer... items);
  public A removeAllFromItems(Collection<APIServer> items);
  public A removeMatchingFromItems(Predicate<APIServerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<APIServer> getItems();
  public List<APIServer> buildItems();
  public APIServer buildItem(Integer index);
  public APIServer buildFirstItem();
  public APIServer buildLastItem();
  public APIServer buildMatchingItem(Predicate<APIServerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<APIServerBuilder> predicate);
  public A withItems(List<APIServer> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.APIServer... items);
  public Boolean hasItems();
  public APIServerListFluent.ItemsNested<A> addNewItem();
  public APIServerListFluent.ItemsNested<A> addNewItemLike(APIServer item);
  public APIServerListFluent.ItemsNested<A> setNewItemLike(Integer index,APIServer item);
  public APIServerListFluent.ItemsNested<A> editItem(Integer index);
  public APIServerListFluent.ItemsNested<A> editFirstItem();
  public APIServerListFluent.ItemsNested<A> editLastItem();
  public APIServerListFluent.ItemsNested<A> editMatchingItem(Predicate<APIServerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,APIServerFluent<APIServerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/APIServerListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface APIServerListFluent<A extends APIServerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,APIServer item);
  public A setToItems(int index,APIServer item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.APIServer... items);
  public A addAllToItems(Collection<APIServer> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.APIServer... items);
  public A removeAllFromItems(Collection<APIServer> items);
  public A removeMatchingFromItems(Predicate<APIServerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<APIServer> getItems();
  public List<APIServer> buildItems();
  public APIServer buildItem(int index);
  public APIServer buildFirstItem();
  public APIServer buildLastItem();
  public APIServer buildMatchingItem(Predicate<APIServerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<APIServerBuilder> predicate);
  public A withItems(List<APIServer> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.APIServer... items);
  public Boolean hasItems();
  public APIServerListFluent.ItemsNested<A> addNewItem();
  public APIServerListFluent.ItemsNested<A> addNewItemLike(APIServer item);
  public APIServerListFluent.ItemsNested<A> setNewItemLike(int index,APIServer item);
  public APIServerListFluent.ItemsNested<A> editItem(int index);
  public APIServerListFluent.ItemsNested<A> editFirstItem();
  public APIServerListFluent.ItemsNested<A> editLastItem();
  public APIServerListFluent.ItemsNested<A> editMatchingItem(Predicate<APIServerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,APIServerFluent<APIServerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
